*** Name: Unidimensional Poverty **** 
*** Purpose: Calculation of FGT measures using STATA ***
*** by: Mauricio Apablaza ***

*** Before start
clear all
set memory 500m
set more off

*** Starting
log using "unidimensional_poverty.log", replace
cd "d:\Delft\"

*** From yesterday 1 *****************************************************************************************
use "suman.dta"

* Generate poverty line
gen z=10
label variable z "poverty line"

* Poverty identificator
gen poor=(income<z)
label variable poor "Headcount FGT0"

* Poverty gap
gen pg=(z-income)/z
replace pg=0 if poor==0
label variable pg "Poverty gap FGT1"

* Squared Poverty gap
gen spg=pg^2
label variable spg "Squared Poverty gap FGT2"

* results
tabstat  poor pg spg, by(country)

* results country 1
su poor pg spg if country==1
*net install poverty, replace
poverty income if country==1, line(10) h pgr fgt3

* results country 2
su poor pg spg if country==2
poverty income if country==2, line(10) h pgr fgt3

* results country 3
su poor pg spg if country==2
poverty income if country==2, line(10) h pgr fgt3

*** CDFPLOT
*net install cdfplot
cdfplot income, by(country)

*** Not elegant correction (we will add rows with 0s to start the graph from cero)
set obs 13
replace country = 1 in 13
replace income = 0 in 13
set obs 14
replace country = 2 in 14
replace income = 0 in 14
set obs 15
replace country = 3 in 15
replace income = 0 in 15
cdfplot income, by(country)

*** From yesterday 2 *****************************************************************************************

use "suman2.dta", clear
cdfplot income, by (country)


*** From New One *****************************************************************************************

use "Sample_Bhutan.dta", clear

* Generate poverty line
gen z=1096.94
label variable z "poverty line"

* Poverty identificator
gen poor=(pce_real<z)
label variable poor "Headcount FGT0"

* Poverty gap
gen pg=(z-pce_real)/z
replace pg=0 if poor==0
label variable pg "Poverty gap FGT1"

* Squared Poverty gap
gen spg=pg^2
label variable spg "Squared Poverty gap FGT2"

* results
tabstat  poor pg spg [aw=weight], by(area)
tabstat  poor pg spg  [aw=weight], by(dcode)

*plot
cdfplot pce_real [aw=weight], by(area)

*** Closing the Log
log close
